nsink_prep_streams: Prepare streams data for N-Sink

View source: R/nsink_prep_data.R

nsink_prep_streamsR Documentation

Prepare streams data for N-Sink

Description

Standardizes streams data by transforming data, clipping to HUC, ...

Usage

nsink_prep_streams(huc_sf, data_dir)

Arguments

huc_sf

An sf object of the Watershed Boundaries Dataset HUC12

data_dir

Base directory that contains N-Sink data folders. Data may be downloaded with the nsink_get_data function.

Value

returns an sf object of the NHDPlus streams for the huc_sf


USEPA/nsink documentation built on Feb. 8, 2025, 12:27 p.m.